@@ -22,14 +22,14 @@ def load_tutorial_file(tutorial_file):
     
     #Load file
     if filename.split('.')[-1] == 'csv':
-        headers = np.genfromtxt(stream, delimiter=',', names=True).dtype.names
-        data = np.genfromtxt(stream, delimiter=',', skip_header=1)
+        data = np.genfromtxt(stream, delimiter=',', names = True)
+        headers = data.dtype.names
     elif filename.split('.')[-1] == 'pt':
-        headers = []
         data = torch.load(stream, map_location=torch.device('cpu'))
-    else:
         headers = []
+    else:
         data = []
+        headers = []
         print('This datatype is not supported by this function')    
     
     return headers, data
